disk

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2024 License: MPL-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DataSourceDiskImage

func DataSourceDiskImage() *schema.Resource

DataSourceDiskImage Data source to get from the api a specific template using the code of the image

Types

type TemplateDisk

type TemplateDisk struct {
	ID      string
	Name    string
	Version string
	Label   string
}

TemplateDisk is a temporal struct to get all template in one place

Jump to